--[[
	Title: Utilities

	Some utility functions. Unlike the functions in misc.lua, this file only holds HL2 specific functions.
]]


--[[
	Function: execFile

	Executes a file on the console. Use this instead of the "exec" command when the config lies outside the cfg folder.

	Parameters:

        	f - The file, relative to the data folder.
		ply - The player to execute on. Leave nil to execute on server. (Ignores this param on client)

	Returns:

		The string of the serialized variable
]]
function ULib.execFile( f, ply )
	if not file.Exists( f ) then
		ULib.error( "Called execFile with invalid file! " .. file )
		return
	end

	local f = ULib.stripComments( file.Read( f ), "//" )
	local lines = string.Explode( "\n", f )

	for _, line in ipairs( lines ) do
		line = string.Trim( line )
		if line ~= "" then
			if SERVER then
				if not ply then
					game.ConsoleCommand( line .. "\n" )
				else
					ply:ConCommand( line .. "\n" )
				end
			else
				LocalPlayer():ConCommand( line .. "\n" )
			end
		end
	end
end


--[[
	Function: serialize

	Serializes a variable. It basically converts a variable into a runnable code string. It works correctly with inline tables.

	Parameters:

		v - The variable you wish to serialize

	Returns:

		The string of the serialized variable
]]
function ULib.serialize( v )
	local t = type( v )
	local str
	if t == "string" then
		str = string.format( "%q", v )
	elseif t == "boolean" or t == "number" then
		str = tostring( v )
	elseif t == "table" then
		str = table.ToString( v )
	elseif t == "Vector" then
		str = "Vector(" .. v.x .. "," .. v.y .. "," .. v.z .. ")"
	elseif t == "Angle" then
		str = "Angle(" .. v.pitch .. "," .. v.yaw .. "," .. v.roll .. ")"
	elseif t == "table" then
		str = table.ToString( v )
	elseif t == "nil" then
		str = "nil"
	else
		ULib.error( "Passed an invalid parameter to serialize! (type: " .. t .. ")" )
		return
	end
	return str
end